UiPath Documentation
automation-suite
2.2510
true
uipathctl-Referenzhandbuch
Wichtig :
Bitte beachten Sie, dass dieser Inhalt teilweise mithilfe von maschineller Übersetzung lokalisiert wurde. Es kann 1–2 Wochen dauern, bis die Lokalisierung neu veröffentlichter Inhalte verfügbar ist.

uipathctl config orchestrator update-config

Aktualisieren Sie die benutzerdefinierte Orchestrator-Konfiguration in der Automation Suite.

Beschreibung​

Aktualisieren Sie die benutzerdefinierte Konfiguration der Orchestrator-Komponente.

Der Befehl verwendet standardmäßig den aktuellen Kontext in der kubeconfig -Datei. Wenn das Flag --kubeconfig gesetzt ist, wird die durch das Flag angegebene kubeconfig -Datei verwendet.

uipathctl config orchestrator update-config [flags]
uipathctl config orchestrator update-config [flags]

Beispiele​

# Update orchestrator nlog configuration from the cluster
uipathctl config orchestrator update-config --nlog-config nlog.custom.json

# Update orchestrator app settings configuration from the cluster
uipathctl config orchestrator update-config --app-settings appsettings.custom.json

# Update orchestrator nlog configuration from the cluster identified by the current context in the kubeconfig file
uipathctl config orchestrator update-config --nlog-config nlog.custom.json --kubeconfig cluster.kubeconfig
# Update orchestrator nlog configuration from the cluster
uipathctl config orchestrator update-config --nlog-config nlog.custom.json

# Update orchestrator app settings configuration from the cluster
uipathctl config orchestrator update-config --app-settings appsettings.custom.json

# Update orchestrator nlog configuration from the cluster identified by the current context in the kubeconfig file
uipathctl config orchestrator update-config --nlog-config nlog.custom.json --kubeconfig cluster.kubeconfig

Optionen​

      --app-settings string   path to application settings config file in json format
  -h, --help                  help for update-config
      --namespace string      The namespace where UiPath Automation Suite is deployed (default "uipath")
      --nlog-config string    path to nlog config file in json format
      --app-settings string   path to application settings config file in json format
  -h, --help                  help for update-config
      --namespace string      The namespace where UiPath Automation Suite is deployed (default "uipath")
      --nlog-config string    path to nlog config file in json format

Von übergeordneten Befehlen geerbte Optionen​

      --context string      name of the kubeconfig context to use
  -f, --force               override all user prompts to true
      --kubeconfig string   kubectl configuration file (default: ~/.kube/config)
      --log-format string   log format. one of [text,json] (default "text")
      --log-level string    set log level. one of [trace,debug,info,error] (default "info")
  -q, --quiet               suppress all output except for errors and warnings
      --timeout duration    timeout of the command (default: 90 minutes) (default 1h30m0s)
      --versions string     optional path to versions file
      --context string      name of the kubeconfig context to use
  -f, --force               override all user prompts to true
      --kubeconfig string   kubectl configuration file (default: ~/.kube/config)
      --log-format string   log format. one of [text,json] (default "text")
      --log-level string    set log level. one of [trace,debug,info,error] (default "info")
  -q, --quiet               suppress all output except for errors and warnings
      --timeout duration    timeout of the command (default: 90 minutes) (default 1h30m0s)
      --versions string     optional path to versions file
  • Beschreibung​
  • Beispiele​
  • Optionen​
  • Von übergeordneten Befehlen geerbte Optionen​

War diese Seite hilfreich?

Verbinden

Benötigen Sie Hilfe? Support

Möchten Sie lernen? UiPath Academy

Haben Sie Fragen? UiPath-Forum

Auf dem neuesten Stand bleiben